@@ -577,8 +577,7 @@ class SQLiteBackendImpl(BackendImpl):
 @BackendImpl.impl.dispatch_for("postgresql")
 class PostgresqlBackendImpl(BackendImpl):
     def create_opportunistic_driver_url(self):
-        return "postgresql://openstack_citest:openstack_citest"\
-            "@localhost/postgres"
+        return "postgresql+psycopg2://openstack_citest:openstack_citest@localhost/postgres"  # noqa: E501
 
     def create_named_database(self, engine, ident, conditional=False):
         with engine.connect().execution_options(
@@ -605,9 +604,11 @@ class PostgresqlBackendImpl(BackendImpl):
         return bool(
             engine.scalar(
                 sqlalchemy.text(
-                    "SELECT datname FROM pg_database "
-                    "WHERE datname=:name"), name=ident)
+                    "SELECT datname FROM pg_database WHERE datname=:name"
+                ),
+                {'name': ident},
             )
+        )
 
     def _close_out_database_users(self, conn, ident):
         """Attempt to guarantee a database can be dropped.
@@ -631,7 +632,9 @@ class PostgresqlBackendImpl(BackendImpl):
                     "WHERE usename=current_user AND "
                     "pid != pg_backend_pid() AND "
                     "datname=:dname"
-                ), dname=ident)
+                ),
+                {'dname': ident},
+            )
 
 
 def _random_ident():
